@@ -12,7 +12,7 @@ use {
 #[async_trait(?Send)]
 impl DBMut for ODBCDatabase {
 	async fn insert_data(&mut self, table_name: &str, rows: Vec<Row>) -> Result<()> {
-		for rows in rows.chunks(1_000){
+		for rows in rows.chunks(255){
 			self.insert(table_name, rows.to_vec()).await ?;
 		}
 		Ok(())
@@ -92,7 +92,7 @@ fn into_buffer(values: Vec<Value>, column_def: Column) -> AnyColumnBuffer {
 				.collect(),
 		),
 		Str => {
-			let mut col = TextColumn::new(255, values.len() * 1000);
+			let mut col = TextColumn::new(50, values.len());
 			values.into_iter().enumerate().for_each(|(index, value)| {
 				let text: String = value.cast().unwrap();
 				col.append(index, Some(text.as_bytes()))
